@@ -1,4 +1,4 @@
-use c3p0::postgres::deadpool;
+use c3p0::postgres::deadpool::{self, Runtime};
 use c3p0::postgres::tokio_postgres::NoTls;
 use c3p0::postgres::*;
 use maybe_single::nio::*;
@@ -35,7 +35,7 @@ async fn init() -> MaybeType {
     pool_config.timeouts.wait = Some(Duration::from_secs(5));
     config.pool = Some(pool_config);
 
-    let c3p0 = PgC3p0Pool::new(config.create_pool(NoTls).unwrap());
+    let c3p0 = PgC3p0Pool::new(config.create_pool(Some(Runtime::Tokio1), NoTls).unwrap());
 
     let repo_manager = RepoManager::new(c3p0.clone());
 
